@@ -2,50 +2,66 @@ import re
 import random
 
 
-class Network:
-    '''Contain a network of interconnected `Node` objects.
+class Node:
+    '''Contain a named node, with weighted connections.
 
-    Attributes:
+    Attributes
     --
-    - `self.all_nodes`: `set` of all nodes in this network (default
-    `set()`).
-    - `self.name`: `name` of this network (type `str`, default `''`).
-    - `self.isolated_nodes`: `set` of all nodes with no connections.
-    - `self.connections`: `list` of all connections in this `Network`.
+    - `self.name`: name of this `Node` (type `str`).
+    - `self.connections`: list of connected `Node` objects (inital
+    value `[]`).
 
-    Methods:
+    Methods
     --
-    - `self.update()`: update `self.connections` and
-    `self.isolated_nodes`; run when `Node` objects in this network have
-    changed.
+    - `self.connect(other, weight)`: add `Connection` between `self`
+    and `other` with `weight`.
+    - `self.disconnect(other, weight)`: remove `Connection` between
+    `self` and `other` with `weight`.
+    - `self.isolate()`: disconnect from all connected `Node` objects.
+
+    Example:
+    --
+    >>> a = Node('A')
+    >>> b = Node('B')
+    >>> a.connect(b, 3)
+    >>> print(a)
+    graph {
+        "A" -- "B" [label=3]
+    }
     '''
 
-    def __init__(self, all_nodes=None, name=None):
-        self.all_nodes = set(all_nodes) if all_nodes else set()
-        self.name = str(name) if name else ''
-        self.update()  # set self.isolated_nodes and self.connections
+    def __init__(self, name):
+        self.name = str(name)
+        self.connections = []
 
     def __str__(self):
-        return dotgraph(self.isolated_nodes, self.connections, self.name)
+        if self.connections:
+            return dotgraph(connections=self.connections)
+        return dotgraph(isolated_nodes=[self])
 
-    def update(self):
-        '''Update `self.connections` and `self.isolated_nodes`; run
-        when `Node` objects in this network have changed.
+    def __hash__(self):
+        return hash(id(self))
+
+    def __eq__(self, other):
+        return id(self) == id(other)
+
+    def connect(self, other, weight=None):
+        '''Add `Connection` between `self` and `other` with
+        `weight`.
         '''
-        self.isolated_nodes = set()
+        self.connections.append(Connection(self, other, weight))
+        other.connections.append(Connection(other, self, weight))
+
+    def disconnect(self, other, weight=None):
+        '''Remove `Connection` between `self` and `other` with
+        `weight`.
+        '''
+        self.connections.remove(Connection(self, other, weight))
+        other.connections.remove(Connection(other, self, weight))
+
+    def isolate(self):
+        '''Disconnect from all connected `Node` objects.'''
         self.connections = []
-        seen = set()  # store reverses of seen connections
-        for node in self.all_nodes:
-            if node.connections:
-                for con in node.connections:
-                    if con.reverse() in seen:
-                        # just node2 of an already-stored connection -> ignore
-                        continue
-                    else:
-                        self.connections.append(con)
-                        seen.add(con)
-            else:
-                self.isolated_nodes.add(node)
 
 
 class Connection:
@@ -98,69 +114,57 @@ class Connection:
         '''Return:
         --
         A DOT language representation of this `Connection` object.'''
-        unlabeled = (f'{escape_dot_id(self.node1.name)}: '
+        unlabeled = (f'{escape_dot_id(self.node1.name)} -- '
                      f'{escape_dot_id(self.node2.name)}')
         if self.weight:
             return unlabeled + f' [label={self.weight}]'
         return unlabeled
 
 
-class Node:
-    '''Contain a named node, with weighted connections.
+class Network:
+    '''Contain a network of interconnected `Node` objects.
 
-    Attributes
+    Attributes:
     --
-    - `self.name`: name of this `Node` (type `str`).
-    - `self.connections`: list of connected `Node` objects (inital
-    value `[]`).
+    - `self.all_nodes`: `set` of all nodes in this network (default
+    `set()`).
+    - `self.name`: `name` of this network (type `str`, default `''`).
+    - `self.isolated_nodes`: `set` of all nodes with no connections.
+    - `self.connections`: `list` of all connections in this `Network`.
 
-    Methods
+    Methods:
     --
-    - `self.connect(other, weight)`: add `Connection` between `self`
-    and `other` with `weight`.
-    - `self.disconnect(other, weight)`: remove `Connection` between
-    `self` and `other` with `weight`.
-    - `self.isolate()`: disconnect from all connected `Node` objects.
-
-    Example:
-    --
-    >>> a = Node('A')
-    >>> b = Node('B')
-    >>> a.connect(b, 3)
-    >>> print(a)
-    graph {
-        "A"
-    }
+    - `self.update()`: update `self.connections` and
+    `self.isolated_nodes`; run when `Node` objects in this network have
+    changed.
     '''
 
-    def __init__(self, name):
-        self.name = str(name)
-        self.connections = []
+    def __init__(self, all_nodes=None, name=None):
+        self.all_nodes = set(all_nodes) if all_nodes else set()
+        self.name = str(name) if name else ''
+        self.update()  # set self.isolated_nodes and self.connections
 
     def __str__(self):
-        if self.connections:
-            return dotgraph(connections=self.connections)
-        return dotgraph(isolated_nodes=[self])
+        return dotgraph(self.isolated_nodes, self.connections, self.name)
 
-    def __hash__(self):
-        return hash(id(self))
-
-    def __eq__(self, other):
-        return id(self) == id(other)
-
-    def connect(self, other, weight=None):
-        '''Add `Connection` between `self` and `other` with `weight`.'''
-        self.connections.append(Connection(self, other, weight))
-        other.connections.append(Connection(other, self, weight))
-
-    def disconnect(self, other, weight=None):
-        '''Remove `Connection` between `self` and `other` with `weight`.'''
-        self.connections.remove(Connection(self, other, weight))
-        other.connections.remove(Connection(other, self, weight))
-
-    def isolate(self):
-        '''Disconnect from all connected `Node` objects.'''
+    def update(self):
+        '''Update `self.connections` and `self.isolated_nodes`; run
+        when `Node` objects in this network have changed.
+        '''
+        self.isolated_nodes = set()
         self.connections = []
+        seen = set()  # store reverses of seen connections
+        for node in self.all_nodes:
+            if node.connections:
+                for con in node.connections:
+                    if con.reverse() in seen:
+                        # just node2 of an already-stored connection -> ignore
+                        continue
+                    else:
+                        self.connections.append(con)
+                        seen.add(con)
+            else:
+                self.isolated_nodes.add(node)
 
 
 class Path:
@@ -168,8 +172,15 @@ class Path:
 
     Attributes
     --
-    `weight`: sum of the weights of all of the `Connection` objects in
-    this `Path` (type: `int`).
+    - `self.connections`: `list` of all `Connection` objects in this
+    `Path`.
+    - `self.weight`: sum of the weights of all `Connection` objects in
+    this `Path` (usually numerical).
+
+    Methods
+    --
+    - `self.__add__(other)`: return a combined `Path` of `self` and
+    `other`.
     '''
 
     def __init__(self, connections=None):
@@ -179,6 +190,10 @@ class Path:
         return dotgraph(connections=self.connections)
 
     def __add__(self, other):
+        '''Return:
+        --
+        - A combined `Path` of `self` and `other`.
+        '''
         return Path(self.connections + other.connections)
 
     @property
@@ -244,6 +259,26 @@ def shortest_path(start, end, _visited=None):
         pass
 
 
+def escape_dot_id(string):
+    '''Surround in double quotes and escape all double quotes.
+
+    Arguments:
+    --
+    - `string`: the id to escape (type `str`).
+
+    Return:
+    --
+    A valid, escaped id for a DOT graph (type `str`).
+
+    Example:
+    --
+    >>> escape_dot_id('A"B')
+    '"A\\"B"'
+    '''
+
+    return '"' + re.sub(r'([\\"])', r'\\\1', string) + '"'
+
+
 def dotgraph(isolated_nodes=None, connections=None, name=''):
     '''Generate a DOT graph out of nodes and connections.
 
@@ -289,28 +324,8 @@ def dotgraph(isolated_nodes=None, connections=None, name=''):
             f'{{\n\t{nodes}{middle}{edges}\n}}')
 
 
-def escape_dot_id(string):
-    '''Surround in double quotes and escape all double quotes.
-
-    Arguments:
-    --
-    - `string`: the id to escape (type `str`).
-
-    Return:
-    --
-    A valid, escaped id for a DOT graph (type `str`).
-
-    Example:
-    --
-    >>> escape_dot_id('A"B')
-    '"A\\"B"'
-    '''
-
-    return '"' + re.sub(r'([\\"])', r'\\\1', string) + '"'
-
-
-def generate_map(n_nodes=10, lower_bound=1, upper_bound=11,
-                 connection_prob=0.8):
+def generate_network(n_nodes=10, lower_bound=1, upper_bound=11,
+                     connection_prob=0.8):
     '''Arguments:
     --
     - `n_nodes`: number of nodes (type `int`, default `10`).
